summaryrefslogtreecommitdiff
path: root/hints/aix.sh
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2000-02-26 02:48:23 +0000
committerJarkko Hietaniemi <jhi@iki.fi>2000-02-26 02:48:23 +0000
commit10cc9d2a36974e2e1175dbda57d8d05e2b0ce49e (patch)
treee1e4f9735fc7ee12c9722ea1365f6d3d9155a383 /hints/aix.sh
parent6b49d2665cf5b4cee8758bc654f9290f3855049e (diff)
downloadperl-10cc9d2a36974e2e1175dbda57d8d05e2b0ce49e.tar.gz
Rename use64bits to use64bitint;
rename usefull64bits to use64bitall. p4raw-id: //depot/cfgperl@5261
Diffstat (limited to 'hints/aix.sh')
-rw-r--r--hints/aix.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/hints/aix.sh b/hints/aix.sh
index 4addec6e0c..1029a36aea 100644
--- a/hints/aix.sh
+++ b/hints/aix.sh
@@ -179,7 +179,7 @@ EOCBU
# after it has prompted the user for whether to use large files.
cat > UU/uselfs.cbu <<'EOCBU'
case "$uselargefiles" in
-$define|true|[yY]*)
+''|$define|true|[yY]*)
lfcflags="`getconf XBS5_ILP32_OFFBIG_CFLAGS 2>/dev/null`"
lfldflags="`getconf XBS5_ILP32_OFFBIG_LDFLAGS 2>/dev/null`"
# _Somehow_ in AIX 4.3.1.0 the above getconf call manages to
@@ -208,10 +208,10 @@ $define|true|[yY]*)
esac
EOCBU
# This script UU/use64bits.cbu will get 'called-back' by Configure
# after it has prompted the user for whether to use 64 bits.
-cat > UU/use64bits.cbu <<'EOCBU'
-case "$use64bits" in
+cat > UU/use64bitint.cbu <<'EOCBU'
+case "$use64bitint" in
$define|true|[yY]*)
case "`oslevel`" in
3.*|4.[012].*)
@@ -208,10 +208,10 @@ $define|true|[yY]*)
esac
EOCBU
-# This script UU/use64bits.cbu will get 'called-back' by Configure
+# This script UU/use64bitint.cbu will get 'called-back' by Configure
# after it has prompted the user for whether to use 64 bits.